package com.ruoyi.web.work.controller;

import java.util.Arrays;
import java.util.List;

import com.ruoyi.common.annotation.Anonymous;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.web.work.domain.Pv2;
import com.ruoyi.web.work.service.IPv2Service;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 住院信息2
 * @author lsw
 * @date 2024-07-19
 */
@Api(tags = "住院信息管理")
@Anonymous
@RestController
@RequestMapping("/work/pv2")
public class Pv2Controller extends BaseController {
    @Autowired
    private IPv2Service pv2Service;

    @ApiOperation(value = "获取住院信息列表")
    @Anonymous
    //@PreAuthorize("@ss.hasPermi('work:pv2:list')")
    @GetMapping("/list")
    public TableDataInfo list(Pv2 pv2){
        startPage();
        List<Pv2> list = pv2Service.selectList(pv2);
        return getDataTable(list);
    }

    @ApiOperation(value = "根据id查询住院信息")
    @Anonymous
   // @PreAuthorize("@ss.hasPermi('work:pv2:query')")
    @GetMapping(value = "/detail/{id}")
    public AjaxResult detail(@PathVariable("id") Long id){
        return AjaxResult.success(pv2Service.getById(id));
    }

    @ApiOperation(value = "添加住院信息")
    @Anonymous
   // @PreAuthorize("@ss.hasPermi('work:pv2:add')")
    @Log(title = "住院信息2", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    public AjaxResult add(@RequestBody Pv2 pv2){
        return toAjax(pv2Service.save(pv2));
    }

    @ApiOperation(value = "修改住院信息")
    @Anonymous
    //@PreAuthorize("@ss.hasPermi('work:pv2:edit')")
    @Log(title = "住院信息2", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody Pv2 pv2){
        return toAjax(pv2Service.updateById(pv2));
    }

    @ApiOperation(value = "删除住院信息")
    @Anonymous
    //@PreAuthorize("@ss.hasPermi('work:pv2:remove')")
    @Log(title = "住院信息2", businessType = BusinessType.DELETE)
    @GetMapping("/remove/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids){
        return toAjax(pv2Service.removeByIds(Arrays.asList(ids)));
    }
}
